#
# Copyright 2001 by Object Craft P/L, Melbourne, Australia.
#
# LICENCE - see LICENCE file distributed with this software for details.
#
#
# Basic functionality tests - save and restore a single context
#
# $Id: session_common.py 15353 2010-01-18 09:09:09Z andrewm $
#

import re
import unittest

class DummyCookieRequest:
    """
    A dummy Request-like class that serves to record the user's session id
    """
    def __init__(self):
        self.cookie = None

    def get_method(self):
        return 'GET'

    def write_header(self, hdr, value):
        if hdr == 'Set-Cookie':
            self.cookie = value

    def get_header(self, hdr):
        if hdr == 'Cookie':
            return self.cookie

    def end_headers(self):
        pass


class DummyFieldRequest:

    def __init__(self):
        self.fieldre = re.compile(r'<input type="hidden" name="(__al[a-zA-Z0-9]*__)" value="([^"]*)" />', re.I|re.M|re.S)
        self.fields = {}
        self.__content_parts = []

    def has_field(self, field):
        return field in self.fields

    def field_value(self, field):
        return self.fields[field]

    def write_content(self, data):
        self.__content_parts.append(data)

    def flush_content(self):
        data = ''.join(self.__content_parts)
        match = self.fieldre.search(data)
        if match:
            key = match.group(1)
            value = match.group(2)
            self.fields[key] = value


class SessionCommon(unittest.TestCase):

    def runTest(self):

        test_str = "Green Eggs and Ham"

        session = self.new_session()

        ctx = session.new_context()
        ctx.load_session()
        self.assertEqual(ctx.locals.__dict__, {})
        ctx.locals.test_var = test_str
        ctx.add_session_vars('test_var')
        ctx.test_save()

        ctx = session.new_context()
        ctx.load_session()
        self.assertEqual(ctx.locals.__dict__.keys(), ['test_var'])
        self.assertEqual(ctx.locals.test_var, test_str)
