#
# Copyright 2001 by Object Craft P/L, Melbourne, Australia.
#
# LICENCE - see LICENCE file distributed with this software for details.
#
# Test <al-namespace> functionality
#
# $Id: namespace.py 16916 2011-04-07 00:13:44Z andrewm $

import unittest
import albatross
import template_common

class Namespace:

    class Nested:
        def __init__(self):
            self.apple = 'Granny Smith'

    def __init__(self, apple='Fuji'):
        self.namespace_name = 'banana'
        self.apple = apple
        self.banana = self.Nested()


class NamespaceCase(template_common.TemplateTestCommon):

    template_dir = 'namespace'

    def test_missing_name(self):
        self.str_tmpl_exc('<al-namespace />')
        self.str_tmpl_exc('<al-namespace name />')
        self.str_tmpl_exc('<al-namespace name='' />')
        self.ctx.locals.bah = None
        self.str_tmpl_exc('<al-namespace nameexpr="bah" />')

    def test_unclosed(self):
        self.str_tmpl_exc('<al-namespace name="foo">')

    def test_null(self):
        self.ctx.locals.foo = Namespace()
        self.html_test('null.html', '')

    def test_value(self):
        self.ctx.locals.foo = Namespace()
        self.ctx.locals.apple = 'Lady Fingers'
        self.html_test('value.html', 'Lady Fingers,\nFuji')

    def test_input(self):
        self.ctx.locals.foo = Namespace()
        self.html_test('input.html', 
                       '<input name="apple" />'
                       '<input name="foo.apple" value="Fuji" />'
                       '<input name="pear" />')

    def test_select(self):
        self.ctx.locals.foo = Namespace()
        self.html_test('select.html', '<select name="foo.apple"></select>')

    def test_textarea(self):
        self.ctx.locals.foo = Namespace()
        self.html_test('textarea.html', 
                       '<textarea name="foo.apple">Fuji</textarea>')

    def test_nameexpr(self):
        self.ctx.locals.namespace_name = 'foo'
        self.ctx.locals.foo = Namespace()
        self.html_test('nameexpr.html', 
                       '<input name="foo.apple" value="Fuji" />')

    def test_nested(self):
        self.ctx.locals.foo = Namespace()
        self.html_test('nested.html', 
                       '<input name="foo.apple" value="Fuji" />'
                       '<input name="foo.banana.apple" value="Granny Smith" />')

    def test_macro(self):
        self.ctx.locals.foo = Namespace()
        self.html_test('macro.html', 
                       '<input name="apple" />'
                       '<input name="foo.apple" value="Fuji" />')

    def test_lookup(self):
        self.ctx.locals.apple = 'Lady Fingers'
        self.ctx.locals.foo = Namespace()
        self.html_test('lookup.html', 
                       "Not an apple.\nIt's an apple!")

    def test_for(self):
        self.ctx.locals.apples = [
            Namespace(), Namespace('Pink Lady'), Namespace('Jonathan')
        ]
        self.html_test('for.html', 
                       '<input name="apples[0].apple" value="Fuji" />'
                       '<input name="apples[1].apple" value="Pink Lady" />'
                       '<input name="apples[2].apple" value="Jonathan" />')

    def test_for_namespace(self):
        self.ctx.locals.apples = [
            Namespace(), Namespace('Pink Lady'), Namespace('Jonathan')
        ]
        self.html_test('for-namespace.html', 
                       '<input name="apples[0].apple" value="Fuji" />'
                       '<input name="apples[1].apple" value="Pink Lady" />'
                       '<input name="apples[2].apple" value="Jonathan" />')

    def test_expand(self):
        self.ctx.locals.apple = 'Lady Fingers'
        self.ctx.locals.foo = Namespace()
        self.ctx.locals.namespace_name = 'bah'
        self.ctx.locals.bah = Namespace('Pink Lady')
        self.html_test('expand.html', 
                       '<input name="apple" value="Lady Fingers" />'
                       '<input name="foo.apple" value="Fuji" />'
                       '<input name="bah.apple" value="Pink Lady" />')


if __name__ == '__main__':
    unittest.main()
